# Dagon - An Asynchronous Task Graph Execution Engine

*Dagon* is a job execution system designed for speed, flexibility,
expressiveness, and correctness with two overarching goals in mind:

1. It should be *easy* to use *correctly*.
2. It should be *hard* to use *incorrectly*.

Dagon itself can be used as a development tool, a CI tool, an application
framework, or a library for creating declarative task-graph programs and
pipelines.

For more information, refer to the `docs/` subdirectory.
